namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<int>::type Progress::span_size_get() const
{
   int __return_value =  ::efl_ui_progress_span_size_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::span_size_set( ::efl::eolian::in_traits<int>::type size) const
{
    ::efl_ui_progress_span_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(size));
}
inline ::efl::eolian::return_traits<double>::type Progress::progress_value_get() const
{
   double __return_value =  ::efl_ui_progress_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::progress_value_set( ::efl::eolian::in_traits<double>::type val) const
{
    ::efl_ui_progress_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Progress::unit_format_get() const
{
   const char * __return_value =  ::efl_ui_progress_unit_format_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::unit_format_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type units) const
{
    ::efl_ui_progress_unit_format_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(units));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<int>::type Progress::span_size_get() const
{
   int __return_value =  ::efl_ui_progress_span_size_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::span_size_set( ::efl::eolian::in_traits<int>::type size) const
{
    ::efl_ui_progress_span_size_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(size));
}
inline ::efl::eolian::return_traits<double>::type Progress::progress_value_get() const
{
   double __return_value =  ::efl_ui_progress_value_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::progress_value_set( ::efl::eolian::in_traits<double>::type val) const
{
    ::efl_ui_progress_value_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<double,  ::efl::eolian::in_traits<double>::type>(val));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Progress::unit_format_get() const
{
   const char * __return_value =  ::efl_ui_progress_unit_format_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Progress::unit_format_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type units) const
{
    ::efl_ui_progress_unit_format_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(units));
}
inline efl::ui::Progress::operator ::efl::ui::Progress() const { return *static_cast< ::efl::ui::Progress const*>(static_cast<void const*>(this)); }
inline efl::ui::Progress::operator ::efl::ui::Progress&() { return *static_cast< ::efl::ui::Progress*>(static_cast<void*>(this)); }
inline efl::ui::Progress::operator ::efl::ui::Progress const&() const { return *static_cast< ::efl::ui::Progress const*>(static_cast<void const*>(this)); }
} } }

